package com.ibm.broker.mqimqe.example;

/*------------------------------------------------------------------------------*/
/* Licensed Materials - Property of IBM                                         */
/*                                                                              */
/*                              MQSeries Everyplace                             */
/*                              ===================                             */
/*                                                                              */
/*                                                                              */
/* Copyright IBM Corp 2001.  All rights reserved.                               */
/*                                                                              */
/* US Government Users Restricted Rights - Use, Duplication or disclosure       */
/* restricted by GSA ADP Schedule Contract with IBM Corp.                       */
/*------------------------------------------------------------------------------*/
import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import examples.application.*;
import java.io.File;
import examples.administration.simple.*;

public class SetupMQeExample1 extends ExampleAdminBase
{
		String routeDest1       =   "ServerQM1";
		String routeAddress1    =   "Network://127.0.0.1:8081";
		String routeDest2;
		
		String routeCommand1    =   null;
		String routeOptions1    =   null;
		static String iniFileName;
public SetupMQeExample1() throws Exception {
	super();
}
public SetupMQeExample1(String args[]) throws Exception {
	routeDest1 = args[0]; // MQe server
	routeAddress1 = "Network://" + args[2] + ":" + args[3]; // route address
	routeCommand1 = null;
	routeOptions1 = null;
	routeDest2 = args[4]; // MQ series queue manager name (not MQe queue manager name)
}
public SetupMQeExample1(String QMgrName) throws Exception {
	super(QMgrName);
}
protected void addRoutes() throws Exception {
	System.out.println("..Setup an admin message to add some routes ");

	// Create an empty queue manager admin message and parameters field
	MQeConnectionAdminMsg msg = new MQeConnectionAdminMsg(routeDest1);

	// Prime message with who to reply to and a unique identifier
	MQeFields msgTest = primeAdminMsg(msg);

	// Set the admin action to create a new queue
	// The connection is setup to use a default channel. This is an alias
	// which must have be setup on the queue manager for the connection to be
	// valid.
	msg.create(routeAddress1, routeCommand1, routeOptions1, "DefaultChannel", "Example route 1");

	//  Put the admin message to the admin queue
	System.out.println("..Put admin message to QM/queue: " + qMgrName + "/AdminQ");
	myQM.putMessage(qMgrName, "AdminQ", msg, null, 0);

	// Wait a while for the response message
	MQeAdminMsg respMsg = waitForReply(msgTest);
	checkReply(respMsg);

	// Create a named connection to the message broker, but specifying
	// the address of the MQe server QM. Requests will be sent to the 
	// MQe Server QM, which will in turn put them to the message brokers
	// BridgeQueue.
	MQeConnectionAdminMsg msg2 = new MQeConnectionAdminMsg(routeDest2);

	// Prime message with who to reply to and a unique identifier
	MQeFields msgTest2 = primeAdminMsg(msg2);

	// Set the admin action to create a new queue
	// The connection is setup to use a default channel. This is an alias
	// which must have be setup on the queue manager for the connection to be
	// valid.
	msg2.create(routeAddress1, routeCommand1, routeOptions1, "DefaultChannel", "Example route 2");

	//  Put the admin message to the admin queue
	System.out.println("..Put admin message to QM/queue: " + qMgrName + "/AdminQ");
	myQM.putMessage(qMgrName, "AdminQ", msg2, null, 0);

	// Wait a while for the response message
	MQeAdminMsg respMsg2 = waitForReply(msgTest2);
	checkReply(respMsg2);
	System.out.println("..Added route to the message broker");
	System.out.println("..Add Routes Successful");
}
/**
 * Creates the StoreAndForwardQueue that will hold messages from the broker
 */
protected void createSandFQueue() throws Exception {
	String newForwardQueue = "ForwardQueue";
	System.out.println("..Setup an admin message to create queue " + newForwardQueue);
	// Now create store and forward queue

	MQeStoreAndForwardQueueAdminMsg msg = 
		new MQeStoreAndForwardQueueAdminMsg(qMgrName, newForwardQueue);
	
	MQeFields parms = new MQeFields();

	// Prime message with who to reply to and a unique identifier
	MQeFields msgTest = primeAdminMsg(msg);

	// Set the admin action to create a new queue
	msg.create(parms);

	//  Put the admin message to the admin queue
	System.out.println("..Put admin message to QM/queue: " + qMgrName + "/AdminQ");
	System.out.println("going to put msg now....");
	myQM.putMessage(qMgrName, "AdminQ", msg, null, 0);

	// Wait a while for the response message
	MQeAdminMsg respMsg = waitForReply(msgTest);

	// Check that a good reply was received
	checkReply(respMsg);
	System.out.println("StoreAndForward Queue created successfully");
}
/**
 * All work is performed in this method
 */
public void doIt() throws Exception {
	try {
		System.out.println("Adding route to: " + routeDest2);
		// Add route to remote QM
		addRoutes();
		// Create a store and forward queue
		createSandFQueue();
	} catch (Exception e) {
		e.printStackTrace();
		System.out.println(example + " Failed! " + e);
	} finally {
		// Clean up
		close();
	}
}
public static void main(String args[]) throws Exception {
	// Check that we have the correct number of parameters
	if (args.length == 5) {
		// Create an instance of the class and call the doIt() method
		iniFileName = args[1]; // Client config file name
		new SetupMQeExample1(args).doIt();
	} else {
		System.out.println("The required parameters are:");
		System.out.println("1] MQe queue manager name");
		System.out.println("2] Client configuration .ini file");
		System.out.println("3] IP address of server");
		System.out.println("4] Port number used by MQe server");
		System.out.println("5] MQSeries queue manager name used by the broker:");
	}
}
/**
 * Over-ride default parameter settings.
 */
public void setParms() {
	startupIni = iniFileName;
}
}