package com.ibm.broker.mqimqe.example;

/*------------------------------------------------------------------------------*/
/* Licensed Materials - Property of IBM                                         */
/*                                                                              */
/*                              MQSeries Everyplace                             */
/*                              ===================                             */
/*                                                                              */
/*                                                                              */
/* Copyright IBM Corp 2001.  All rights reserved.                               */
/*                                                                              */
/* US Government Users Restricted Rights - Use, Duplication or disclosure       */
/* restricted by GSA ADP Schedule Contract with IBM Corp.                       */
/*------------------------------------------------------------------------------*/
import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import examples.application.*;
import examples.administration.simple.*;
import java.io.File;

public class SetupMQeExample2 extends ExampleAdminBase {
	String newQueue = "Inbox";
	static String iniFileName;
public SetupMQeExample2(String QMgrName) throws Exception {
	super(QMgrName);
}
/**
 * create a "real" queue to place messages from the message broker
 */
protected void createMsgQueue() throws Exception {
	System.out.println("..Setup an admin message to create queue " + newQueue);

	// Create an empty queue admin message and parameters field
	MQeQueueAdminMsg msg2 = new MQeQueueAdminMsg(qMgrName, newQueue);
	MQeFields parms = new MQeFields();

	// Prime message with who to reply to and a unique identifier
	MQeFields msgTest = primeAdminMsg(msg2);

	// Set the admin action to create a new queue
	msg2.create(parms);
	
	// Put the admin message to the admin queue
	System.out.println("..Put admin message to QM/queue: " + qMgrName + "/AdminQ");
	myQM.putMessage(qMgrName, "AdminQ", msg2, null, 0);

	// Wait a while for the response message
	MQeAdminMsg respMsg = waitForReply(msgTest);

	// Check that a good reply was receive
	checkReply(respMsg);
	System.out.println("..Queue creation Successful");
}
/**
 * All work is performed in this method
 */
public void doIt() throws Exception {
	try {
		// create a queue called Inbox
		createMsgQueue();
	} catch (Exception e) {
		e.printStackTrace();
		System.out.println(example + " Failed! " + e);
	} finally {
		// Clean up
		close();
	}
}
public static void main(String args[]) throws Exception {
	// Check that we have the correct number of parameters
	if (args.length == 2) {
		// Create an instance of the class and call the doIt() method
		iniFileName = args[1]; // Client config file name
		new SetupMQeExample2(args[0]).doIt();
	} else {
		System.out.println("The required parameters are:");
		System.out.println("1] MQe queue manager name");
		System.out.println("2] Client configuration .ini file");
	}
}
/**
 * Over-ride default parameter settings.
 */
public void setParms() {
	startupIni = iniFileName;
}
}